@@ -80,8 +80,8 @@ FINANCIAL_STATEMENT_QUERY = lambda cik, kind, api_key :'''
 
 CREATE_NEW_USER_MUTATION = lambda email, name, photoUrl : '''
     mutation{
-    createUser(email:"%s",name:"%s",photoUrl:"%s"){ok}
-    }
+        createUser(email:"%s",name:"%s",photoUrl:"%s")
+        }
     '''%(email,name,photoUrl)
 
 def take_a_sec():
